#This program tests whether the alpha's are the same for the data of Abdellaoui et al. (2011)

library(readxl)
library(BayesFactor)
library(AICcmodavg)
library(lme4)
library(nlme)
library(lmerTest)

SSR <- read_excel("ABPW2_alpha.xlsx", col_names = FALSE)
colnames(SSR)<-c("risk","Paris", "For","Stock")



alpha<-append(SSR$risk,SSR$Paris)
alpha<-append(alpha,SSR$For)
alpha<-append(alpha,SSR$Stock)

Source<-c(rep("risk",58),rep("Paris",58),rep("Foreign",58),rep("Stock",58))


ID1<-rep(1:58,4)
Fit_total<-data.frame(ID1,Source,alpha)

#Simple anova

one.way<-aov(alpha~Source,data=Fit_total)
summary(one.way)

#With subject as random effect

block<-aov(alpha~Source+ID1,data=Fit_total)
summary(block)

model.set <- list(one.way, block)
model.names <- c("one.way","blocking")

#Test which model fits better
aictab(model.set, modnames = model.names)

tukey.one.way<-TukeyHSD(one.way)
tukey.one.way

#Same using lmer function to estimate mixed effects model

model = lmer(alpha ~ Source + (1|ID1),
             data=Fit_total,
             REML=TRUE)

anova(model)
ranova(model)
summary(model)

model.fixed = gls(alpha~Source,
                  data=Fit_total,
                  method="REML")

anova(model,
      model.fixed)

