library(tidyverse)
library(readr)
library(viridis)
library(reshape)
library(hrbrthemes)
library(latex2exp)
library(gridExtra)
library(grid)
library(ggthemes)
library(extrafont)
library(plyr)
library(BayesFactor)
library(ggplot2)
library(viridis)
library(AICcmodavg)
library(lme4)
library(nlme)
library(lmerTest)
Cons_Han <- read_excel("Cons.xlsx")

t.test(Cons_Han$CT1,Cons_Han$CT2,paired=T)
cor.test(Cons_Han$CT1,Cons_Han$CT2)
wilcox.test(Cons_Han$CT1,Cons_Han$CT2,paired=T)
ttestBF(Cons_Han$CT1,Cons_Han$CT2,paired=T)

t.test(Cons_Han$PT1,Cons_Han$PT2,paired=T)
cor.test(Cons_Han$PT1,Cons_Han$PT2)

wilcox.test(Cons_Han$PT1,Cons_Han$PT2,paired=T)
ttestBF(Cons_Han$PT1,Cons_Han$PT2,paired=T)

t.test(Cons_Han$BF1,Cons_Han$BF2,paired=T)
cor.test(Cons_Han$BF1,Cons_Han$BF2)
wilcox.test(Cons_Han$BF1,Cons_Han$BF2,paired=T)
ttestBF(Cons_Han$BF1,Cons_Han$BF2,paired=T)

New_Han<-Cons_Han[-c(9,12,16),]

t.test(New_Han$CT1,New_Han$CT2,paired=T)
cor.test(New_Han$CT1,New_Han$CT2)

wilcox.test(New_Han$CT1,New_Han$CT2,paired=T)
ttestBF(New_Han$CT1,New_Han$CT2,paired=T)

t.test(New_Han$PT1,New_Han$PT2,paired=T)
cor.test(New_Han$PT1,New_Han$PT2)

wilcox.test(New_Han$PT1,New_Han$PT2,paired=T)
ttestBF(New_Han$PT1,New_Han$PT2,paired=T)

t.test(New_Han$BF1,New_Han$BF2,paired=T)
cor.test(Cons_Han$BF1,Cons_Han$BF2)

wilcox.test(New_Han$BF1,New_Han$BF2,paired=T)
ttestBF(New_Han$BF1,New_Han$BF2,paired=T)

a_half<-append(Cons_Han$CT1,Cons_Han$CT2)
a_half<-append(a_half,Cons_Han$BF1)
a_half<-append(a_half,Cons_Han$BF2)
a_half<-append(a_half,Cons_Han$PT1)
a_half<-append(a_half,Cons_Han$PT2)

Treat<-rep(c(rep("org",48),rep("check",48)),3)
ID<- rep(1:48,6)

aov_df<-data.frame(ID,a_half,Treat)

res.aov<-aov(a_half~Treat,data=aov_df)
summary(res.aov)

model = lmer(a_half ~ Treat + (1|ID),
                 data=aov_df,
                 REML=TRUE)

anova(model)
ranova(model)
summary(model)


anovaBF(a_half~Treat+ID, data=aov_df,whichRandom="ID")

####plots

col1<-c("#42049EFF")
col2<-c("#A62098FF")
col3<-c("#E76F5BFF")
col4<-c("#FCCE25FF")


orgCT<-aov_df$a_half[1:48]
repCT<-aov_df$a_half[49:96]

CT<-data.frame(orgCT,repCT)


lab_ct<-paste("rho==",0.96)

p_ct<-ggplot(data=CT,aes(x=orgCT,y=repCT))+theme_ipsum()+
  geom_point(aes(orgCT,repCT),col=col1,size=2)+geom_line(aes(orgCT,orgCT),lty=2,col=col4)+
  labs(title="Canberra temperature",x="Original",y="Replication")+
  scale_x_continuous(breaks=c(15,20,25))+
  scale_y_continuous(breaks=c(10,15,20,25))+
  annotate("text",x=15.5,y=5,label="12",size=2,colour=col1)+
  annotate("text",x=18,y=5,label="16",size=2,colour=col1)+
  annotate("text",x=26,y=18,label=lab_ct,size=3,colour=col1,parse=TRUE)+
  
  theme(plot.background = element_rect(fill = "white"),
        panel.background = element_rect(fill = 'white', color = 'white'),
        plot.title=element_text(family="Dubai",face = "plain",size=10),
        axis.text.x=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.text.y=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.title.y=element_text(family="Dubai",angle=0,face = "plain",size=8),
        axis.title.x=element_text(family="Dubai",angle=0,face = "plain",size=8,hjust=.8))
p_ct

ggsave("Consistency Canberra temp.png",plot=p_ct,width=4,height=4,dpi=2000)

orgBF<-aov_df$a_half[97:144]
repBF<-aov_df$a_half[145:192]

BF<-data.frame(orgBF,repBF)


lab_bf<-paste("rho==",0.97)

p_bf<-ggplot(data=BF,aes(x=orgBF,y=repBF))+theme_ipsum()+
  geom_point(aes(orgBF,repBF),col=col2,size=2)+geom_line(aes(orgBF,orgBF),lty=2,col=col4)+
  labs(title="Match attendance",x="Original",y="Replication")+
  scale_x_continuous(breaks=c(25,50,75,100))+
  scale_y_continuous(breaks=c(25,50,75,100))+
  annotate("text",x=48,y=31,label="12",size=2,colour=col2)+
#  annotate("text",x=18,y=5,label="16",size=2,colour=col1)+
  annotate("text",x=86,y=65,label=lab_bf,size=3,colour=col2,parse=TRUE)+
  
  theme(plot.background = element_rect(fill = "white"),
        panel.background = element_rect(fill = 'white', color = 'white'),
        plot.title=element_text(family="Dubai",face = "plain",size=10),
        axis.text.x=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.text.y=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.title.y=element_text(family="Dubai",angle=0,face = "plain",size=8),
        axis.title.x=element_text(family="Dubai",angle=0,face = "plain",size=8,hjust=.8))
p_bf

ggsave("Consistency match attendance.png",plot=p_bf,width=4,height=4,dpi=2000)

###Paris

orgpt<-aov_df$a_half[193:240]
reppt<-aov_df$a_half[241:288]

pt<-data.frame(orgpt,reppt)


lab_pt<-paste("rho==",0.82)

p_pt<-ggplot(data=pt,aes(x=orgpt,y=reppt))+theme_ipsum()+
  geom_point(aes(orgpt,reppt),col=col3,size=2)+geom_line(aes(orgpt,orgpt),lty=2,col=col4)+
  labs(title="Paris temperature",x="Original",y="Replication")+
  scale_x_continuous(breaks=c(0,10,20))+
  scale_y_continuous(breaks=c(0,10,20))+
  annotate("text",x=0,y=17,label="9",size=2,colour=col3)+
  annotate("text",x=6.7,y=13,label="12",size=2,colour=col3)+
  annotate("text",x=3,y=11,label="16",size=2,colour=col3)+
  annotate("text",x=23,y=12,label=lab_pt,size=3,colour=col3,parse=TRUE)+
  annotate("text",x=16.7,y=24.5,label="5",size=2,colour=col3)+
  
  
  theme(plot.background = element_rect(fill = "white"),
        panel.background = element_rect(fill = 'white', color = 'white'),
        plot.title=element_text(family="Dubai",face = "plain",size=10),
        axis.text.x=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.text.y=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.title.y=element_text(family="Dubai",angle=0,face = "plain",size=8),
        axis.title.x=element_text(family="Dubai",angle=0,face = "plain",size=8,hjust=.8))
p_pt

ggsave("Consistency Paris temp.png",plot=p_pt,width=4,height=4,dpi=2000)
