library(readxl)
library(BayesFactor)
library(AICcmodavg)
library(lme4)
library(nlme)
library(lmerTest)
library(tidyverse)
library(readr)
library(viridis)
library(reshape)
library(hrbrthemes)
library(latex2exp)
library(gridExtra)
library(grid)
library(ggthemes)
library(extrafont)
library(plyr)
library(ggplot2)
library(viridis)


#correlation alpha and FORA

Test2_Han <- read_excel("Test2.xlsx")
t.test(Test2_Han$FORA)
ttestBF(Test2_Han$FORA)

new_data<-subset(Test2_Han, Test2_Han$FORA!=0)

cor.test(Test2_Han$alpha,Test2_Han$FORA)
cor.test(new_data$alpha,new_data$FORA)
correlationBF(new_data$alpha,new_data$FORA)

#plot

cor.df<-data.frame(new_data$alpha,new_data$FORA)

lab_ct<-paste("rho==",0.51)
lab_x<-expression(alpha)
col1<-c("#3E4A89FF")
col2<-c("#6DCD59FF")
col3<-c("#1F9E89FF")
p_cor<-ggplot(data=cor.df,aes(x=new_data$alpha,y=new_data$FORA))+theme_ipsum()+
  geom_point(aes(new_data$alpha,new_data$FORA),col=col1,size=2)+
  stat_smooth(method = "lm",
              formula = y ~ x,
              geom = "smooth",col=col3,lty=2,fill=col2,alpha=.2)+
  labs(title="First order risk aversion",x=lab_x,y="")+
  scale_x_continuous(breaks=c(0,.25,.50,.75,1),labels=c("0","0.25","0.50","0.75","1"))+
  scale_y_continuous(breaks=c(0,5,10,15,20),labels=c("0","5","10","15","20"))+
  annotate("text",x=.6,y=15,label=lab_ct,size=3,colour=col1,parse=TRUE)+
  
  theme(plot.background = element_rect(fill = "white"),
        panel.background = element_rect(fill = 'white', color = 'white'),
        plot.title=element_text(family="Dubai",face = "plain",size=9,hjust=-0.15),
        axis.text.x=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.text.y=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.title.y=element_text(family="Dubai",angle=0,face = "plain",size=8),
        axis.title.x=element_text(family="Dubai",angle=0,face = "plain",size=11,vjust=0,hjust=.85))
p_cor

ggsave("Correlation_alpha_FORA.png",plot=p_cor,width=4,height=4,dpi=2000)


#ANOVA alpha's

Data_alpha <- read_excel("C:/Users/User/Dropbox (Erasmus Universiteit Rotterdam)/HurwiczEU/Revision/Data estimations for parametric group/Test_alpha_Han.xlsx", 
                             col_names = c("Paris","Match","Canberra"))

cor.test(Data_alpha$Paris,Data_alpha$Match)
correlationBF(Data_alpha$Paris,Data_alpha$Match)

cor.test(Data_alpha$Paris,Data_alpha$Canberra)
correlationBF(Data_alpha$Paris,Data_alpha$Canberra)

cor.test(Data_alpha$Match,Data_alpha$Canberra)
correlationBF(Data_alpha$Match,Data_alpha$Canberra)

alpha<-append(Data_alpha$Paris,Data_alpha$Match)
alpha<-append(alpha,Data_alpha$Canberra)
ID<-rep(1:48,3)
Group<-c(rep("Paris",48),rep("Match",48),rep("Canberra",48))
df_alpha<-data.frame(ID,alpha,Group)

alpha.aov<-aov(alpha~Group,data=df_alpha)
summary(alpha.aov)

model = lmer(alpha ~ Group+(1|ID),
                 data=df_alpha,
                 REML=TRUE)

anova(model)
ranova(model)
summary(model)

####plots


alphaC<-Data_alpha$Canberra
alphaP<-Data_alpha$Paris
alphaM<-Data_alpha$Match

#Paris match

lab_ct<-paste("rho==",0.68)
col1<-c("#481A6CFF")
col2<-c("#3C4F8AFF")
col3<-c("#297A8EFF")
col4<-c("#1FA287FF")
col5<-c("#5AC864FF")
col6<-c("#C6E021FF")
alpha_plot<-data.frame(alphaP,alphaM,alphaC)

par_mat<-ggplot(data=alpha_plot,aes(x=alphaP,y=alphaM))+theme_ipsum()+
  geom_point(aes(alphaP,alphaM),col=col1,size=2)+
  stat_smooth(method = "lm",
              formula = y ~ x,
              geom = "smooth",col="grey50",lty=2,fill=col4,alpha=.2)+
  labs(title="Match",x="Paris",y="")+
  scale_x_continuous(breaks=c(0,.25,.5,.75,1),labels=c("0","0.25","0.50","0.75","1"))+
  scale_y_continuous(breaks=c(0,.25,.5,.75,1),labels=c("0","0.25","0.50","0.75","1"))+
  annotate("text",x=.85,y=.5,label=lab_ct,size=3,colour=col1,parse=TRUE)+
  
  theme(plot.background = element_rect(fill = "white"),
        panel.background = element_rect(fill = 'white', color = 'white'),
        plot.title=element_text(family="Dubai",face = "plain",size=9,hjust=-0.05),
        axis.text.x=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.text.y=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.title.y=element_text(family="Dubai",angle=0,face = "plain",size=8),
        axis.title.x=element_text(family="Dubai",angle=0,face = "plain",size=9,vjust=0,hjust=.85))
par_mat

ggsave("Correlation_alpha_Paris_match_exp1.png",plot=par_mat,width=4,height=4,dpi=2000)

#Paris Canberra

lab_ct<-paste("rho==",0.56)

par_can<-ggplot(data=alpha_plot,aes(x=alphaP,y=alphaC))+theme_ipsum()+
  geom_point(aes(alphaP,alphaC),col=col2,size=2)+
  stat_smooth(method = "lm",
              formula = y ~ x,
              geom = "smooth",col="grey50",lty=2,fill=col5,alpha=.2)+
  labs(title="Canberra",x="Paris",y="")+
  scale_x_continuous(breaks=c(0,.25,.5,.75,1),labels=c("0","0.25","0.50","0.75","1"))+
  scale_y_continuous(breaks=c(0,.25,.5,.75,1),labels=c("0","0.25","0.50","0.75","1"))+
  annotate("text",x=.55,y=.85,label=lab_ct,size=3,colour=col1,parse=TRUE)+
  
  theme(plot.background = element_rect(fill = "white"),
        panel.background = element_rect(fill = 'white', color = 'white'),
        plot.title=element_text(family="Dubai",face = "plain",size=9,hjust=-0.05),
        axis.text.x=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.text.y=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.title.y=element_text(family="Dubai",angle=0,face = "plain",size=8),
        axis.title.x=element_text(family="Dubai",angle=0,face = "plain",size=9,vjust=0,hjust=.85))
par_can

ggsave("Correlation_alpha_Paris_Canberra_exp1.png",plot=par_can,width=4,height=4,dpi=2000)

#Match Canberra

lab_ct<-paste("rho==",0.76)

mat_can<-ggplot(data=alpha_plot,aes(x=alphaM,y=alphaC))+theme_ipsum()+
  geom_point(aes(alphaM,alphaC),col=col3,size=2)+
  stat_smooth(method = "lm",
              formula = y ~ x,
              geom = "smooth",col="grey50",lty=2,fill=col6,alpha=.2)+
  labs(title="Canberra",x="Match",y="")+
  scale_x_continuous(breaks=c(0,.25,.5,.75,1),labels=c("0","0.25","0.50","0.75","1"))+
  scale_y_continuous(breaks=c(0,.25,.5,.75,1),labels=c("0","0.25","0.50","0.75","1"))+
  annotate("text",x=.85,y=.45,label=lab_ct,size=3,colour=col1,parse=TRUE)+
  
  theme(plot.background = element_rect(fill = "white"),
        panel.background = element_rect(fill = 'white', color = 'white'),
        plot.title=element_text(family="Dubai",face = "plain",size=9,hjust=-0.05),
        axis.text.x=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.text.y=element_text(family="Dubai",angle=0,face = "plain",size=7),
        axis.title.y=element_text(family="Dubai",angle=0,face = "plain",size=8),
        axis.title.x=element_text(family="Dubai",angle=0,face = "plain",size=9,vjust=0,hjust=.85))
mat_can

ggsave("Correlation_alpha_Match_Canberra_exp1.png",plot=mat_can,width=4,height=4,dpi=2000)




#correlation diff alpha diff beta

Diff_alpha_beta <- read_excel("C:/Users/User/Dropbox (Erasmus Universiteit Rotterdam)/HurwiczEU/Revision/Data estimations for parametric group/Diff_alpha_beta_han.xlsx", 
                                  col_names = c("diffa","diffb"))

cor.test(Diff_alpha_beta$diffa,Diff_alpha_beta$diffb)
correlationBF(Diff_alpha_beta$diffa,Diff_alpha_beta$diffb)


